#  Melvant - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Melvant.
#
#  Melvant is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Melvant is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Melvant.  If not, see <http://www.gnu.org/licenses/>.

from .handler import Handler


class CallbackQueryHandler(Handler):
    """The CallbackQuery handler class. Used to handle callback queries coming from inline buttons.
    It is intended to be used with :meth:`~melvant.Client.add_handler`

    For a nicer way to register this handler, have a look at the
    :meth:`~melvant.Client.on_callback_query` decorator.

    Parameters:
        callback (``callable``):
            Pass a function that will be called when a new CallbackQuery arrives. It takes *(client, callback_query)*
            as positional arguments (look at the section below for a detailed description).

        filters (:obj:`Filters`):
            Pass one or more filters to allow only a subset of callback queries to be passed
            in your callback function.

    Other parameters:
        client (:obj:`~melvant.Client`):
            The Client itself, useful when you want to call other API methods inside the message handler.

        callback_query (:obj:`~melvant.types.CallbackQuery`):
            The received callback query.
    """

    def __init__(self, callback: callable, filters=None):
        super().__init__(callback, filters)
