#  Melvant - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Melvant.
#
#  Melvant is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Melvant is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Melvant.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from melvant.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from melvant.raw.core import TLObject
from melvant import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class ChatsSlice(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~melvant.raw.base.messages.Chats`.

    Details:
        - Layer: ``140``
        - ID: ``0x9cd81144``

    Parameters:
        count: ``int`` ``32-bit``
        chats: List of :obj:`Chat <melvant.raw.base.Chat>`

    See Also:
        This object can be returned by 7 methods:

        .. hlist::
            :columns: 2

            - :obj:`messages.GetChats <melvant.raw.functions.messages.GetChats>`
            - :obj:`messages.GetCommonChats <melvant.raw.functions.messages.GetCommonChats>`
            - :obj:`messages.GetAllChats <melvant.raw.functions.messages.GetAllChats>`
            - :obj:`channels.GetChannels <melvant.raw.functions.channels.GetChannels>`
            - :obj:`channels.GetAdminedPublicChannels <melvant.raw.functions.channels.GetAdminedPublicChannels>`
            - :obj:`channels.GetLeftChannels <melvant.raw.functions.channels.GetLeftChannels>`
            - :obj:`channels.GetGroupsForDiscussion <melvant.raw.functions.channels.GetGroupsForDiscussion>`
    """

    __slots__: List[str] = ["count", "chats"]

    ID = 0x9cd81144
    QUALNAME = "types.messages.ChatsSlice"

    def __init__(self, *, count: int, chats: List["raw.base.Chat"]) -> None:
        self.count = count  # int
        self.chats = chats  # Vector<Chat>

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "ChatsSlice":
        # No flags
        
        count = Int.read(b)
        
        chats = TLObject.read(b)
        
        return ChatsSlice(count=count, chats=chats)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.count))
        
        b.write(Vector(self.chats))
        
        return b.getvalue()
