#  Melvant - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Melvant.
#
#  Melvant is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Melvant is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Melvant.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from melvant.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from melvant.raw.core import TLObject
from melvant import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class SentEncryptedFile(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~melvant.raw.base.messages.SentEncryptedMessage`.

    Details:
        - Layer: ``140``
        - ID: ``0x9493ff32``

    Parameters:
        date: ``int`` ``32-bit``
        file: :obj:`EncryptedFile <melvant.raw.base.EncryptedFile>`

    See Also:
        This object can be returned by 3 methods:

        .. hlist::
            :columns: 2

            - :obj:`messages.SendEncrypted <melvant.raw.functions.messages.SendEncrypted>`
            - :obj:`messages.SendEncryptedFile <melvant.raw.functions.messages.SendEncryptedFile>`
            - :obj:`messages.SendEncryptedService <melvant.raw.functions.messages.SendEncryptedService>`
    """

    __slots__: List[str] = ["date", "file"]

    ID = 0x9493ff32
    QUALNAME = "types.messages.SentEncryptedFile"

    def __init__(self, *, date: int, file: "raw.base.EncryptedFile") -> None:
        self.date = date  # int
        self.file = file  # EncryptedFile

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "SentEncryptedFile":
        # No flags
        
        date = Int.read(b)
        
        file = TLObject.read(b)
        
        return SentEncryptedFile(date=date, file=file)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.date))
        
        b.write(self.file.write())
        
        return b.getvalue()
