#  Melvant - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Melvant.
#
#  Melvant is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Melvant is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Melvant.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from melvant.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from melvant.raw.core import TLObject
from melvant import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class UpdateShortMessage(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~melvant.raw.base.Updates`.

    Details:
        - Layer: ``140``
        - ID: ``0x313bc7f8``

    Parameters:
        id: ``int`` ``32-bit``
        user_id: ``int`` ``64-bit``
        message: ``str``
        pts: ``int`` ``32-bit``
        pts_count: ``int`` ``32-bit``
        date: ``int`` ``32-bit``
        out (optional): ``bool``
        mentioned (optional): ``bool``
        media_unread (optional): ``bool``
        silent (optional): ``bool``
        fwd_from (optional): :obj:`MessageFwdHeader <melvant.raw.base.MessageFwdHeader>`
        via_bot_id (optional): ``int`` ``64-bit``
        reply_to (optional): :obj:`MessageReplyHeader <melvant.raw.base.MessageReplyHeader>`
        entities (optional): List of :obj:`MessageEntity <melvant.raw.base.MessageEntity>`
        ttl_period (optional): ``int`` ``32-bit``

    See Also:
        This object can be returned by 71 methods:

        .. hlist::
            :columns: 2

            - :obj:`account.GetNotifyExceptions <melvant.raw.functions.account.GetNotifyExceptions>`
            - :obj:`contacts.DeleteContacts <melvant.raw.functions.contacts.DeleteContacts>`
            - :obj:`contacts.AddContact <melvant.raw.functions.contacts.AddContact>`
            - :obj:`contacts.AcceptContact <melvant.raw.functions.contacts.AcceptContact>`
            - :obj:`contacts.GetLocated <melvant.raw.functions.contacts.GetLocated>`
            - :obj:`contacts.BlockFromReplies <melvant.raw.functions.contacts.BlockFromReplies>`
            - :obj:`messages.SendMessage <melvant.raw.functions.messages.SendMessage>`
            - :obj:`messages.SendMedia <melvant.raw.functions.messages.SendMedia>`
            - :obj:`messages.ForwardMessages <melvant.raw.functions.messages.ForwardMessages>`
            - :obj:`messages.EditChatTitle <melvant.raw.functions.messages.EditChatTitle>`
            - :obj:`messages.EditChatPhoto <melvant.raw.functions.messages.EditChatPhoto>`
            - :obj:`messages.AddChatUser <melvant.raw.functions.messages.AddChatUser>`
            - :obj:`messages.DeleteChatUser <melvant.raw.functions.messages.DeleteChatUser>`
            - :obj:`messages.CreateChat <melvant.raw.functions.messages.CreateChat>`
            - :obj:`messages.ImportChatInvite <melvant.raw.functions.messages.ImportChatInvite>`
            - :obj:`messages.StartBot <melvant.raw.functions.messages.StartBot>`
            - :obj:`messages.MigrateChat <melvant.raw.functions.messages.MigrateChat>`
            - :obj:`messages.SendInlineBotResult <melvant.raw.functions.messages.SendInlineBotResult>`
            - :obj:`messages.EditMessage <melvant.raw.functions.messages.EditMessage>`
            - :obj:`messages.GetAllDrafts <melvant.raw.functions.messages.GetAllDrafts>`
            - :obj:`messages.SetGameScore <melvant.raw.functions.messages.SetGameScore>`
            - :obj:`messages.SendScreenshotNotification <melvant.raw.functions.messages.SendScreenshotNotification>`
            - :obj:`messages.SendMultiMedia <melvant.raw.functions.messages.SendMultiMedia>`
            - :obj:`messages.UpdatePinnedMessage <melvant.raw.functions.messages.UpdatePinnedMessage>`
            - :obj:`messages.SendVote <melvant.raw.functions.messages.SendVote>`
            - :obj:`messages.GetPollResults <melvant.raw.functions.messages.GetPollResults>`
            - :obj:`messages.EditChatDefaultBannedRights <melvant.raw.functions.messages.EditChatDefaultBannedRights>`
            - :obj:`messages.SendScheduledMessages <melvant.raw.functions.messages.SendScheduledMessages>`
            - :obj:`messages.DeleteScheduledMessages <melvant.raw.functions.messages.DeleteScheduledMessages>`
            - :obj:`messages.SetHistoryTTL <melvant.raw.functions.messages.SetHistoryTTL>`
            - :obj:`messages.SetChatTheme <melvant.raw.functions.messages.SetChatTheme>`
            - :obj:`messages.HideChatJoinRequest <melvant.raw.functions.messages.HideChatJoinRequest>`
            - :obj:`messages.HideAllChatJoinRequests <melvant.raw.functions.messages.HideAllChatJoinRequests>`
            - :obj:`messages.ToggleNoForwards <melvant.raw.functions.messages.ToggleNoForwards>`
            - :obj:`messages.SendReaction <melvant.raw.functions.messages.SendReaction>`
            - :obj:`messages.GetMessagesReactions <melvant.raw.functions.messages.GetMessagesReactions>`
            - :obj:`messages.SetChatAvailableReactions <melvant.raw.functions.messages.SetChatAvailableReactions>`
            - :obj:`messages.SendWebViewData <melvant.raw.functions.messages.SendWebViewData>`
            - :obj:`help.GetAppChangelog <melvant.raw.functions.help.GetAppChangelog>`
            - :obj:`channels.CreateChannel <melvant.raw.functions.channels.CreateChannel>`
            - :obj:`channels.EditAdmin <melvant.raw.functions.channels.EditAdmin>`
            - :obj:`channels.EditTitle <melvant.raw.functions.channels.EditTitle>`
            - :obj:`channels.EditPhoto <melvant.raw.functions.channels.EditPhoto>`
            - :obj:`channels.JoinChannel <melvant.raw.functions.channels.JoinChannel>`
            - :obj:`channels.LeaveChannel <melvant.raw.functions.channels.LeaveChannel>`
            - :obj:`channels.InviteToChannel <melvant.raw.functions.channels.InviteToChannel>`
            - :obj:`channels.DeleteChannel <melvant.raw.functions.channels.DeleteChannel>`
            - :obj:`channels.ToggleSignatures <melvant.raw.functions.channels.ToggleSignatures>`
            - :obj:`channels.EditBanned <melvant.raw.functions.channels.EditBanned>`
            - :obj:`channels.DeleteHistory <melvant.raw.functions.channels.DeleteHistory>`
            - :obj:`channels.TogglePreHistoryHidden <melvant.raw.functions.channels.TogglePreHistoryHidden>`
            - :obj:`channels.EditCreator <melvant.raw.functions.channels.EditCreator>`
            - :obj:`channels.ToggleSlowMode <melvant.raw.functions.channels.ToggleSlowMode>`
            - :obj:`channels.ConvertToGigagroup <melvant.raw.functions.channels.ConvertToGigagroup>`
            - :obj:`phone.DiscardCall <melvant.raw.functions.phone.DiscardCall>`
            - :obj:`phone.SetCallRating <melvant.raw.functions.phone.SetCallRating>`
            - :obj:`phone.CreateGroupCall <melvant.raw.functions.phone.CreateGroupCall>`
            - :obj:`phone.JoinGroupCall <melvant.raw.functions.phone.JoinGroupCall>`
            - :obj:`phone.LeaveGroupCall <melvant.raw.functions.phone.LeaveGroupCall>`
            - :obj:`phone.InviteToGroupCall <melvant.raw.functions.phone.InviteToGroupCall>`
            - :obj:`phone.DiscardGroupCall <melvant.raw.functions.phone.DiscardGroupCall>`
            - :obj:`phone.ToggleGroupCallSettings <melvant.raw.functions.phone.ToggleGroupCallSettings>`
            - :obj:`phone.ToggleGroupCallRecord <melvant.raw.functions.phone.ToggleGroupCallRecord>`
            - :obj:`phone.EditGroupCallParticipant <melvant.raw.functions.phone.EditGroupCallParticipant>`
            - :obj:`phone.EditGroupCallTitle <melvant.raw.functions.phone.EditGroupCallTitle>`
            - :obj:`phone.ToggleGroupCallStartSubscription <melvant.raw.functions.phone.ToggleGroupCallStartSubscription>`
            - :obj:`phone.StartScheduledGroupCall <melvant.raw.functions.phone.StartScheduledGroupCall>`
            - :obj:`phone.JoinGroupCallPresentation <melvant.raw.functions.phone.JoinGroupCallPresentation>`
            - :obj:`phone.LeaveGroupCallPresentation <melvant.raw.functions.phone.LeaveGroupCallPresentation>`
            - :obj:`folders.EditPeerFolders <melvant.raw.functions.folders.EditPeerFolders>`
            - :obj:`folders.DeleteFolder <melvant.raw.functions.folders.DeleteFolder>`
    """

    __slots__: List[str] = ["id", "user_id", "message", "pts", "pts_count", "date", "out", "mentioned", "media_unread", "silent", "fwd_from", "via_bot_id", "reply_to", "entities", "ttl_period"]

    ID = 0x313bc7f8
    QUALNAME = "types.UpdateShortMessage"

    def __init__(self, *, id: int, user_id: int, message: str, pts: int, pts_count: int, date: int, out: Optional[bool] = None, mentioned: Optional[bool] = None, media_unread: Optional[bool] = None, silent: Optional[bool] = None, fwd_from: "raw.base.MessageFwdHeader" = None, via_bot_id: Optional[int] = None, reply_to: "raw.base.MessageReplyHeader" = None, entities: Optional[List["raw.base.MessageEntity"]] = None, ttl_period: Optional[int] = None) -> None:
        self.id = id  # int
        self.user_id = user_id  # long
        self.message = message  # string
        self.pts = pts  # int
        self.pts_count = pts_count  # int
        self.date = date  # int
        self.out = out  # flags.1?true
        self.mentioned = mentioned  # flags.4?true
        self.media_unread = media_unread  # flags.5?true
        self.silent = silent  # flags.13?true
        self.fwd_from = fwd_from  # flags.2?MessageFwdHeader
        self.via_bot_id = via_bot_id  # flags.11?long
        self.reply_to = reply_to  # flags.3?MessageReplyHeader
        self.entities = entities  # flags.7?Vector<MessageEntity>
        self.ttl_period = ttl_period  # flags.25?int

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "UpdateShortMessage":
        
        flags = Int.read(b)
        
        out = True if flags & (1 << 1) else False
        mentioned = True if flags & (1 << 4) else False
        media_unread = True if flags & (1 << 5) else False
        silent = True if flags & (1 << 13) else False
        id = Int.read(b)
        
        user_id = Long.read(b)
        
        message = String.read(b)
        
        pts = Int.read(b)
        
        pts_count = Int.read(b)
        
        date = Int.read(b)
        
        fwd_from = TLObject.read(b) if flags & (1 << 2) else None
        
        via_bot_id = Long.read(b) if flags & (1 << 11) else None
        reply_to = TLObject.read(b) if flags & (1 << 3) else None
        
        entities = TLObject.read(b) if flags & (1 << 7) else []
        
        ttl_period = Int.read(b) if flags & (1 << 25) else None
        return UpdateShortMessage(id=id, user_id=user_id, message=message, pts=pts, pts_count=pts_count, date=date, out=out, mentioned=mentioned, media_unread=media_unread, silent=silent, fwd_from=fwd_from, via_bot_id=via_bot_id, reply_to=reply_to, entities=entities, ttl_period=ttl_period)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 1) if self.out else 0
        flags |= (1 << 4) if self.mentioned else 0
        flags |= (1 << 5) if self.media_unread else 0
        flags |= (1 << 13) if self.silent else 0
        flags |= (1 << 2) if self.fwd_from is not None else 0
        flags |= (1 << 11) if self.via_bot_id is not None else 0
        flags |= (1 << 3) if self.reply_to is not None else 0
        flags |= (1 << 7) if self.entities else 0
        flags |= (1 << 25) if self.ttl_period is not None else 0
        b.write(Int(flags))
        
        b.write(Int(self.id))
        
        b.write(Long(self.user_id))
        
        b.write(String(self.message))
        
        b.write(Int(self.pts))
        
        b.write(Int(self.pts_count))
        
        b.write(Int(self.date))
        
        if self.fwd_from is not None:
            b.write(self.fwd_from.write())
        
        if self.via_bot_id is not None:
            b.write(Long(self.via_bot_id))
        
        if self.reply_to is not None:
            b.write(self.reply_to.write())
        
        if self.entities:
            b.write(Vector(self.entities))
        
        if self.ttl_period is not None:
            b.write(Int(self.ttl_period))
        
        return b.getvalue()
